@@ -2,6 +2,7 @@ import os
 import platform
 import re
 import sys
+import warnings
 from contextlib import contextmanager
 from typing import Any
 from typing import Callable
@@ -25,13 +26,16 @@ skip_pypy = pytest.mark.skipif(
 # Python 3.8 changed the output formatting (bpo-35500), which has been ported to mock 3.0
 NEW_FORMATTING = sys.version_info >= (3, 8)
 
+if sys.version_info[:2] >= (3, 8):
+    from unittest.mock import AsyncMock
+
 
 @pytest.fixture
 def needs_assert_rewrite(pytestconfig):
     """
     Fixture which skips requesting test if assertion rewrite is disabled (#102)
 
-    Making this a fixture to avoid acessing pytest's config in the global context.
+    Making this a fixture to avoid accessing pytest's config in the global context.
     """
     option = pytestconfig.getoption("assertmode")
     if option != "rewrite":
@@ -211,7 +215,7 @@ class TestMockerStub:
     def test_repr_with_name(self, mocker: MockerFixture) -> None:
         test_name = "funny walk"
         stub = mocker.stub(name=test_name)
-        assert "name={!r}".format(test_name) in repr(stub)
+        assert f"name={test_name!r}" in repr(stub)
 
     def __test_failure_message(self, mocker: MockerFixture, **kwargs: Any) -> None:
         expected_name = kwargs.get("name") or "mock"
@@ -231,6 +235,10 @@ class TestMockerStub:
     @pytest.mark.parametrize("name", (None, "", "f", "The Castle of aaarrrrggh"))
     def test_failure_message_with_name(self, mocker: MagicMock, name: str) -> None:
         self.__test_failure_message(mocker, name=name)
+        
+    @pytest.mark.skipif(sys.version_info[:2] < (3, 8), reason="This Python version doesn't have `AsyncMock`.")
+    def test_async_stub_type(self, mocker: MockerFixture) -> None:
+        assert isinstance(mocker.async_stub(), AsyncMock)
 
 
 def test_instance_method_spy(mocker: MockerFixture) -> None:
@@ -267,19 +275,19 @@ def test_instance_method_spy_exception(
 ) -> None:
     class Foo:
         def bar(self, arg):
-            raise exc_cls("Error with {}".format(arg))
+            raise exc_cls(f"Error with {arg}")
 
     foo = Foo()
     spy = mocker.spy(foo, "bar")
 
     expected_calls = []
     for i, v in enumerate([10, 20]):
-        with pytest.raises(exc_cls, match="Error with {}".format(v)):
+        with pytest.raises(exc_cls, match=f"Error with {v}"):
             foo.bar(arg=v)
 
         expected_calls.append(mocker.call(arg=v))
         assert foo.bar.call_args_list == expected_calls  # type:ignore[attr-defined]
-        assert str(spy.spy_exception) == "Error with {}".format(v)
+        assert str(spy.spy_exception) == f"Error with {v}"
 
 
 def test_instance_method_spy_autospec_true(mocker: MockerFixture) -> None:
@@ -296,7 +304,7 @@ def test_instance_method_spy_autospec_true(mocker: MockerFixture) -> None:
 
 
 def test_spy_reset(mocker: MockerFixture) -> None:
-    class Foo(object):
+    class Foo:
         def bar(self, x):
             if x == 0:
                 raise ValueError("invalid x")
@@ -475,7 +483,6 @@ def test_callable_like_spy(testdir: Any, mocker: MockerFixture) -> None:
     assert spy.spy_return == 20
 
 
-@pytest.mark.asyncio
 async def test_instance_async_method_spy(mocker: MockerFixture) -> None:
     class Foo:
         async def bar(self, arg):
@@ -708,10 +715,14 @@ def test_monkeypatch_no_terminal(testdir: Any) -> None:
 
 def test_standalone_mock(testdir: Any) -> None:
     """Check that the "mock_use_standalone" is being used."""
+    pytest.importorskip("mock")
+
     testdir.makepyfile(
         """
+        import mock
+
         def test_foo(mocker):
-            pass
+            assert mock.MagicMock is mocker.MagicMock
     """
     )
     testdir.makeini(
@@ -721,13 +732,18 @@ def test_standalone_mock(testdir: Any) -> None:
     """
     )
     result = testdir.runpytest_subprocess()
-    assert result.ret == 3
-    result.stderr.fnmatch_lines(["*No module named 'mock'*"])
+    assert result.ret == 0
 
 
 @pytest.mark.usefixtures("needs_assert_rewrite")
 def test_detailed_introspection(testdir: Any) -> None:
     """Check that the "mock_use_standalone" is being used."""
+    testdir.makeini(
+        """
+        [pytest]
+        asyncio_mode=auto
+        """
+    )
     testdir.makepyfile(
         """
         def test(mocker):
@@ -753,12 +769,12 @@ def test_detailed_introspection(testdir: Any) -> None:
         "*Args:",
         "*assert ('fo',) == ('',)",
         "*At index 0 diff: 'fo' != ''*",
-        "*Use -v to get the full diff*",
+        "*Use -v to get more diff*",
         "*Kwargs:*",
         "*assert {} == {'bar': 4}*",
         "*Right contains* more item*",
         "*{'bar': 4}*",
-        "*Use -v to get the full diff*",
+        "*Use -v to get more diff*",
     ]
     result.stdout.fnmatch_lines(expected_lines)
 
@@ -769,11 +785,16 @@ def test_detailed_introspection(testdir: Any) -> None:
 @pytest.mark.usefixtures("needs_assert_rewrite")
 def test_detailed_introspection_async(testdir: Any) -> None:
     """Check that the "mock_use_standalone" is being used."""
+    testdir.makeini(
+        """
+        [pytest]
+        asyncio_mode=auto
+        """
+    )
     testdir.makepyfile(
         """
         import pytest
 
-        @pytest.mark.asyncio
         async def test(mocker):
             m = mocker.AsyncMock()
             await m('fo')
@@ -789,12 +810,12 @@ def test_detailed_introspection_async(testdir: Any) -> None:
         "*Args:",
         "*assert ('fo',) == ('',)",
         "*At index 0 diff: 'fo' != ''*",
-        "*Use -v to get the full diff*",
+        "*Use -v to get more diff*",
         "*Kwargs:*",
         "*assert {} == {'bar': 4}*",
         "*Right contains* more item*",
         "*{'bar': 4}*",
-        "*Use -v to get the full diff*",
+        "*Use -v to get more diff*",
     ]
     result.stdout.fnmatch_lines(expected_lines)
 
@@ -824,6 +845,12 @@ def test_assert_called_with_unicode_arguments(mocker: MockerFixture) -> None:
 
 def test_plain_stopall(testdir: Any) -> None:
     """patch.stopall() in a test should not cause an error during unconfigure (#137)"""
+    testdir.makeini(
+        """
+        [pytest]
+        asyncio_mode=auto
+        """
+    )
     testdir.makepyfile(
         """
         import random
@@ -913,7 +940,7 @@ def test_patch_context_manager_with_context_manager(mocker: MockerFixture) -> No
 
     a = A()
 
-    with pytest.warns(None) as warn_record:
+    with warnings.catch_warnings(record=True) as warn_record:
         with mocker.patch.context_manager(a, "doIt", return_value=True):
             assert a.doIt() is True
 
@@ -958,6 +985,12 @@ def test_abort_patch_context_manager_with_stale_pyc(testdir: Any) -> None:
 
 
 def test_used_with_class_scope(testdir: Any) -> None:
+    testdir.makeini(
+        """
+        [pytest]
+        asyncio_mode=auto
+        """
+    )
     testdir.makepyfile(
         """
         import pytest
@@ -982,6 +1015,12 @@ def test_used_with_class_scope(testdir: Any) -> None:
 
 
 def test_used_with_module_scope(testdir: Any) -> None:
+    testdir.makeini(
+        """
+        [pytest]
+        asyncio_mode=auto
+        """
+    )
     testdir.makepyfile(
         """
         import pytest
@@ -1004,7 +1043,12 @@ def test_used_with_module_scope(testdir: Any) -> None:
 
 
 def test_used_with_package_scope(testdir: Any) -> None:
-    """..."""
+    testdir.makeini(
+        """
+        [pytest]
+        asyncio_mode=auto
+        """
+    )
     testdir.makepyfile(
         """
         import pytest
@@ -1027,7 +1071,12 @@ def test_used_with_package_scope(testdir: Any) -> None:
 
 
 def test_used_with_session_scope(testdir: Any) -> None:
-    """..."""
+    testdir.makeini(
+        """
+        [pytest]
+        asyncio_mode=auto
+        """
+    )
     testdir.makepyfile(
         """
         import pytest
